@@ -27,7 +27,7 @@
 **			   *			   *
 **			   *************************
 */
-#define IMPORT_VERSION "3.7"
+#define VER "3.7"
 
 #include "client_priv.h"
 #include <my_sys.h>
@@ -192,13 +192,6 @@ static const char *load_default_groups[]=
   0 };
 
 
-static void print_version(void)
-{
-  printf("%s  Ver %s Distrib %s, for %s (%s)\n" ,my_progname,
-	  IMPORT_VERSION, MYSQL_SERVER_VERSION,SYSTEM_TYPE,MACHINE_TYPE);
-}
-
-
 static void usage(void)
 {
   puts("Copyright 2000-2008 MySQL AB, 2008 Sun Microsystems, Inc.");
@@ -436,7 +429,7 @@ static void lock_table(MYSQL *mysql, int tablecount, char **raw_tablename)
     dynstr_append(&query, " WRITE,");
   }
   if (mysql_real_query(mysql, query.str, (ulong)query.length-1))
-    db_error(mysql); /* We shall continue here, if --force was given */
+    db_error(mysql); /* We shall countinue here, if --force was given */
 }
 
 
@@ -638,7 +631,7 @@ pthread_handler_t worker_thread(void *arg)
 
   if (mysql_query(mysql, "/*!40101 set @@character_set_database=binary */;"))
   {
-    db_error(mysql); /* We shall continue here, if --force was given */
+    db_error(mysql); /* We shall countinue here, if --force was given */
     goto error;
   }
 
@@ -766,12 +759,12 @@ int main(int argc, char **argv)
     if (!(mysql= db_connect(current_host,current_db,current_user,opt_password)))
     {
       free_defaults(argv_to_free);
-      return(1); /* purecov: dead code */
+      return(1); /* purecov: deadcode */
     }
 
     if (mysql_query(mysql, "/*!40101 set @@character_set_database=binary */;"))
     {
-      db_error(mysql); /* We shall continue here, if --force was given */
+      db_error(mysql); /* We shall countinue here, if --force was given */
       return(1);
     }
 
